@@ -31,8 +31,8 @@ public:
   void setFront(const QString &front);
   void setBack(const QString &back);
 
-  bool frontBackReversed() const;
-  void setFrontBackReversed(bool reverse);
+  bool frontBackReversed() const { return reversed; }
+  void setFrontBackReversed(bool reverse) { reversed = reverse; }
   
 private:
   QString cardFront;
