@@ -33,7 +33,7 @@
 #include <klocale.h>
 #include <kpushbutton.h>
 #include <ksimpleconfig.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 #include <kstdaction.h>
 #include <kcolorbutton.h>
 
@@ -164,7 +164,7 @@ void Kalzium::setupAllElementKPButtons()
 
         //Now we add the WhatsThis-help for each button
         QWhatsThis::add( element[n], i18n("Click here to get information about %1.").arg(eleminfo.Symbol) );
-		QToolTip::add( element[n], eleminfo.Name );
+		QToolTip::add( element[n], eleminfo.Name.utf8() );
     }
 
     //////////////////
