@@ -58,7 +58,14 @@ private: // Private methods
     /** Check if the current document can save */
     bool checkSave();
 
+    /** Save the file, return false if save failed for any reason */
+    bool fileSave();
+    /** Save the file under a user-choosen filename, return false if save as
+        failed for any reason */
+    bool fileSaveAs();
+
 private: // Private attributes
+
     /** KEDUCA file */
     FileRead *_keducaFile;
     /** Recent files */
