@@ -304,7 +304,7 @@ void KStars::initActions() {
 void KStars::initStatusBar() {
 	statusBar()->insertItem( i18n( " Welcome to KStars " ), 0, 1, true );
 	statusBar()->setItemAlignment( 0, AlignLeft | AlignVCenter );
-	QString s = "00:00:00,   +00:00:00";
+	QString s = "00h 00m 00s,   +00d 00\'00\"";
 
 	statusBar()->insertItem( s, 1, 1, true );
 	statusBar()->setItemAlignment( 1, AlignRight | AlignVCenter );
@@ -366,10 +366,33 @@ void KStars::datainitFinished(bool worked) {
 
 	pd->buildGUI();
 	updateTime();
-
 	clock->start();
 	show();
 
+//Check whether initial position is below the horizon.
+//We sued to just call slotCenter() in buildGUI() which performs this check.  
+//However, on a Gentoo system, if the messagebox is shown before show() is called, 
+//the program exits.  It does not crash (at least there are no error messages),
+//it simply exits.  Very strange.
+	if ( options()->useAltAz && options()->drawGround &&
+			map()->focus()->alt().Degrees() < -1.0 ) {
+		QString caption = i18n( "Initial Position is Below Horizon" );
+		QString message = i18n( "The initial position is below the horizon.\nWould you like to reset to the default position?" );
+		if ( KMessageBox::warningYesNo( this, message, caption, 
+				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_start_below_horiz" ) == KMessageBox::Yes ) {
+			map()->setClickedObject( NULL );
+			map()->setFoundObject( NULL );
+			options()->isTracking = false;
+			options()->setSnapNextFocus(true);
+			
+			SkyPoint DefaultFocus;
+			DefaultFocus.setAz( 180.0 );
+			DefaultFocus.setAlt( 45.0 );
+			DefaultFocus.HorizontalToEquatorial( LSTh(), geo()->lat() );
+			map()->setDestination( &DefaultFocus );
+		}
+	}
+
 // just show dialog if option is set (don't force it)	
 	KTipDialog::showTip( "kstars/tips" );
 }
@@ -493,21 +516,22 @@ void KStars::privatedata::buildGUI() {
 			}
 		}
 
-		ks->map()->slotCenter();
+//		ks->map()->slotCenter();
 	} else {
 		ks->map()->setClickedPoint( &newPoint );
-		ks->map()->slotCenter();
+//		ks->map()->slotCenter();
 	}
 
+	ks->map()->setDestination( ks->map()->clickedPoint() );
+	ks->map()->destination()->EquatorialToHorizontal( ks->LSTh(), ks->geo()->lat() );
 	ks->map()->setFocus( ks->map()->destination() );
 	ks->map()->focus()->EquatorialToHorizontal( ks->LSTh(), ks->geo()->lat() );
-	ks->map()->destination()->EquatorialToHorizontal( ks->LSTh(), ks->geo()->lat() );
 
 	ks->setHourAngle();
 
 	ks->map()->setOldFocus( ks->map()->focus() );
-	ks->map()->oldfocus()->setAz( ks->map()->focus()->az() );
-	ks->map()->oldfocus()->setAlt( ks->map()->focus()->alt() );
+	ks->map()->oldfocus()->setAz( ks->map()->focus()->az().Degrees() );
+	ks->map()->oldfocus()->setAlt( ks->map()->focus()->alt().Degrees() );
 
 	kapp->dcopClient()->resume();
 
