@@ -18,12 +18,13 @@
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
 #include <klocale.h>
+#include <dcopclient.h>
 
 #include "kstars.h"
 #include "kstarsdata.h"
 #include "kstarssplash.h"
 
-#define KSTARS_VERSION "0.9"
+#define KSTARS_VERSION "0.9.1"
 
 static const char *description =
 	I18N_NOOP("Desktop Planetarium");
@@ -39,26 +40,43 @@ static KCmdLineOptions options[] =
 int main(int argc, char *argv[])
 {
 
-  KAboutData aboutData( "kstars", I18N_NOOP("KStars"),
-    KSTARS_VERSION, description, KAboutData::License_GPL,
-    "(c) 2001, Jason Harris", 0, "http://edu.kde.org/kstars");
-  aboutData.addAuthor("Jason Harris",0, "jharris@30doradus.org", "http://www.30doradus.org");
-  aboutData.addAuthor("Heiko Evermann",0, "heiko@evermann.de", "http://www.evermann.de");
-  aboutData.addAuthor("Thomas Kabelmann", 0, "tk78@gmx.de", 0);
-  KCmdLineArgs::init( argc, argv, &aboutData );
-  KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
+	KAboutData aboutData( "kstars", I18N_NOOP("KStars"),
+		KSTARS_VERSION, description, KAboutData::License_GPL,
+		"(c) 2001, Jason Harris", 0, "http://edu.kde.org/kstars");
+	aboutData.addAuthor("Jason Harris",0, "jharris@30doradus.org", "http://www.30doradus.org");
+	aboutData.addAuthor("Heiko Evermann",0, "heiko@evermann.de", "http://www.evermann.de");
+	aboutData.addAuthor("Thomas Kabelmann", 0, "tk78@gmx.de", 0);
+	aboutData.addAuthor("Pablo de Vicente", 0, "pvicentea@wanadoo.es", 0);
+	aboutData.addAuthor("Carsten Niehaus", 0, "cniehaus@gmx.de", 0);
+	aboutData.addAuthor("Mark Hollomon", 0, "mhh@mindspring.com", 0);
+	KCmdLineArgs::init( argc, argv, &aboutData );
+	KCmdLineArgs::addCmdLineOptions( options ); // Add our own options.
 
 	KApplication a;
 
+	/*
 	KStarsData *   kstarsData = new KStarsData();
-	KStarsSplash*  splashDialog = new KStarsSplash(kstarsData, 0, "Splash", true );
-	// show splash screen and load KStarsData from data files
-	splashDialog->disableResize();
-	if ( splashDialog->exec()==QDialog::Accepted ) {
+	KStarsSplash*  splashDialog = new KStarsSplash(0, "Splash");
+
+	QObject::connect(kstarsData, SIGNAL( progressText(Qstring) ),
+			splashDialog, SLOT( setMessage(QString) ));
+
+	if (kstarsData->initialize()) {
 		KStars *kstars = new KStars( kstarsData );
 		kstars->show();
 		return a.exec();
 	} else {
 		a.exit(1);
 	}
+	*/
+
+#if (QT_VERSION <= 299)
+	a.dcopClient()->attach();
+	a.dcopClient()->registerAs("kstars");
+#endif
+
+	KStars *kstars = new KStars( true );
+	QObject::connect(kapp, SIGNAL(lastWindowClosed()), kapp, SLOT(quit()));
+	return a.exec();
+
 }
