@@ -31,7 +31,7 @@
 #include <kmessagebox.h>
 #include <kio/job.h>
 #include <kio/netaccess.h>
-#include <kstddirs.h>
+#include <kstandarddirs.h>
 
 // application specific includes
 #include "verbspanish.h"
@@ -420,7 +420,7 @@ bool KVerbosDoc::openDocVERBOS(QFile &f)
 	}; // while (!f.atEnd())
 	emit anzahlVerbenGeaendert(getAnzahl());
 	return true;
-};
+}
 
 // sichert die Datei. Die Verben werden in einer Datei im HTML Format gespeichert.
 bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
@@ -443,7 +443,7 @@ bool KVerbosDoc::saveDocument(const KURL& url, const char *format /*=0*/)
 	file.close();
 	modified=false;
 	return b;
-};
+}
 
 // Die Verben als HTML-Datei abspeichern
 bool KVerbosDoc::saveDocHTML(QFile &f)
@@ -620,7 +620,7 @@ bool KVerbosDoc::saveDocHTML(QFile &f)
   t << "</body>" << endl;
   t << "</html>" << endl;
   return good;
-};
+}
 
 bool KVerbosDoc::saveDocVERBOS(QFile &f)
 {
@@ -655,7 +655,7 @@ bool KVerbosDoc::saveDocVERBOS(QFile &f)
  		};
  	};
   return true;
-};
+}
 
 void KVerbosDoc::deleteContents()
 {
@@ -747,7 +747,7 @@ QString KVerbosDoc::getAuswahl(QString s[][3], int &t)
 		};	
 	};
 	return s[6][1];
-};
+}
 
 spanishVerbList::Iterator KVerbosDoc::findVerb(const QString& s)
 {
