@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_header.cpp,v 1.15 2002/01/19 11:04:02 mhunter Exp $
+    $Id: kva_header.cpp,v 1.18 2002/05/09 09:48:55 arnold Exp $
 
                      header buttons part of kvoctrain
 
@@ -16,6 +16,15 @@
     -----------------------------------------------------------------------
 
     $Log: kva_header.cpp,v $
+    Revision 1.18  2002/05/09 09:48:55  arnold
+    fixed i18n issue
+
+    Revision 1.17  2002/04/23 12:47:52  binner
+    CVS_SILENT Capitalisation fixes.
+
+    Revision 1.16  2002/04/20 12:55:48  binner
+    CVS_SILENT Capitalisation fixes.
+
     Revision 1.15  2002/01/19 11:04:02  mhunter
     CVS_SILENT Corrected typographical errors
 
@@ -156,14 +165,14 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
   header_m = new QPopupMenu();
 
   if (header != KV_COL_ORG - KV_EXTRA_COLS ) {
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create random &query"), (header << 16) | IDH_START_QUERY);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &multiple choice"), (header << 16) | IDH_START_MULTIPLE);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), (header << 16) | IDH_START_QUERY);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), (header << 16) | IDH_START_MULTIPLE);
     header_m->setItemEnabled((header << 16) | IDH_START_MULTIPLE, doc->numLangs() > 1);
     header_m->setItemEnabled((header << 16) | IDH_START_QUERY,  doc->numLangs() > 1);
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("&Verbs"), (header << 16) | IDH_START_VERB);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Articles"), (header << 16) | IDH_START_ARTICLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison forms"), (header << 16) | IDH_START_ADJECTIVE);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Forms"), (header << 16) | IDH_START_ADJECTIVE);
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("S&ynonyms"), (header << 16) | IDH_START_SYNONYM);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("A&ntonyms"), (header << 16) | IDH_START_ANTONYM);
@@ -171,10 +180,10 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), SORT_ALPHA, (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &language"), langs_m, (2 << 16) | IDH_NULL);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/reset.xpm")), i18n("Reset &grades"), (header << 16) | IDH_RESET_GRADE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")), i18n("&Remove column"), (header << 16) | IDH_REMOVE );
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/reset.xpm")), i18n("Reset &Grades"), (header << 16) | IDH_RESET_GRADE);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")), i18n("&Remove Column"), (header << 16) | IDH_REMOVE );
   }
   else {
     QPopupMenu *query_m =  new QPopupMenu();
@@ -195,14 +204,14 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
       if((j = langset.indexShortId(doc->getIdent(i))) >= 0
          && !langset.PixMapFile(j).isEmpty()
          && !langset.longId(j).isEmpty() ) {
-        query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from ")+names[i-1],
+        query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(names[i-1]),
             (i << (16+8)) |  IDH_START_QUERY);  // hack: IDs => header-ids + cmd
       }
       else {
-        query_m->insertItem(i18n("from ")+doc->getIdent(i), (i << (16+8)) |  IDH_START_QUERY);
+        query_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
       }
     }
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create random &query"), query_m, (3 << 16) | IDH_NULL);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), query_m, (3 << 16) | IDH_NULL);
     connect (query_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
     connect (query_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
     for (int i = 1; i < (int) doc->numLangs(); i++) {
@@ -211,18 +220,18 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
       if((j = langset.indexShortId(doc->getIdent(i))) >= 0
          && !langset.PixMapFile(j).isEmpty()
          && !langset.longId(j).isEmpty() ) {
-        multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from ")+names[i-1],
+        multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(names[i-1]),
             (i << (16+8)) |  IDH_START_MULTIPLE);  // hack: IDs => header-ids + cmd
       }
       else {
-        multiple_m->insertItem(i18n("from ")+doc->getIdent(i), (i << (16+8)) |  IDH_START_MULTIPLE);
+        multiple_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
       }
     }
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &multiple choice"), multiple_m, (4 << 16) | IDH_NULL);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("Train &verbs"), (header << 16) | IDH_START_VERB);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Article training"), (header << 16) | IDH_START_ARTICLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison training"), (header << 16) | IDH_START_ADJECTIVE);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("Train &Verbs"), (header << 16) | IDH_START_VERB);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Article Training"), (header << 16) | IDH_START_ARTICLE);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Training"), (header << 16) | IDH_START_ADJECTIVE);
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("&Synonyms"), (header << 16) | IDH_START_SYNONYM);
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("&Antonyms"), (header << 16) | IDH_START_ANTONYM);
@@ -233,7 +242,7 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
 
     header_m->insertSeparator();
     header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), SORT_ALPHA, (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &language"), langs_m, (2 << 16) | IDH_NULL);
+    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
   }
 
   connect (header_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
@@ -601,12 +610,12 @@ void kvoctrainApp::slotHeaderCallBack (int header_and_cmd) /*FOLD00*/
           name = langset.longId(i);
 
         format = i18n("You are about to reset the knowledge data of a "
-                      "whole language.\n\nDo you really want to reset \"%1\" ?");
+                      "whole language.\n\nDo you really want to reset \"%1\"?");
       }
       else {
         name = lessons->text(act_lesson);
         format = i18n("You are about to reset the knowledge data of a "
-                      "lesson.\n\nDo you really want to reset \"%1\" ?");
+                      "lesson.\n\nDo you really want to reset \"%1\"?");
       }
 
       msg = format.arg(name);
