@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: kva_init.cpp,v 1.26 2002/03/13 09:25:42 staikos Exp $
+    $Id: kva_init.cpp,v 1.31 2002/10/23 18:31:10 asserhal Exp $
 
                    initialisation part of kvoctrain
 
@@ -16,6 +16,21 @@
     -----------------------------------------------------------------------
 
     $Log: kva_init.cpp,v $
+    Revision 1.31  2002/10/23 18:31:10  asserhal
+    Corrected i18n
+
+    Revision 1.30  2002/09/17 20:24:59  binner
+    CVS_SILENT Style guide fix, use "cvslastchange" or X-WebCVS header line to view
+
+    Revision 1.29  2002/07/21 04:27:08  binner
+    CVS_SILENT Style guide fixes
+
+    Revision 1.28  2002/04/19 09:12:10  arnold
+    xml structure now more conforming
+
+    Revision 1.27  2002/04/16 17:54:09  binner
+    Capitalisation fixes.
+
     Revision 1.26  2002/03/13 09:25:42  staikos
     Don't crash on exit
 
@@ -105,7 +120,7 @@
 
  ***************************************************************************/
 
-/***************************************************************************
+/*** content ************************************************************************
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -237,7 +252,7 @@ void kvoctrainApp::initMenuBar()
   file_menu->insertItem(KGlobal::iconLoader()->loadIcon("fileopen", KIcon::Small),
                         i18n("&Open..."), ID_FILE_OPEN );
 
-  file_menu->insertItem(i18n("&Open an Example..."), ID_FILE_OPEN_XMP );
+  file_menu->insertItem(i18n("&Open Example..."), ID_FILE_OPEN_XMP );
 
   recent_files_menu = new QPopupMenu();
   connect(recent_files_menu, SIGNAL(activated(int)),   SLOT(slotFileOpenRecent(int)) );
@@ -275,12 +290,12 @@ void kvoctrainApp::initMenuBar()
   edit_menu->insertItem(i18n("Se&lect All"), ID_SEL_ALL );
   edit_menu->insertItem(i18n("Clear Selec&tion"), ID_CLR_SEL );
   edit_menu->insertSeparator();
-  edit_menu->insertItem(KGlobal::iconLoader()->loadIcon("find", KIcon::Small), i18n("&Search from Clipboard"), ID_SEARCH_CLIP );
+  edit_menu->insertItem(KGlobal::iconLoader()->loadIcon("find", KIcon::Small), i18n("&Search From Clipboard"), ID_SEARCH_CLIP );
   edit_menu->insertSeparator();
   edit_menu->insertItem(QPixmap(locate("data", "kvoctrain/append-row.xpm")), i18n("&Append New Entry"), ID_APPEND_ROW );
-  edit_menu->insertItem(QPixmap(locate("data", "kvoctrain/edit-row.xpm")), i18n("&Edit Selected Area"), ID_EDIT_ROW );
+  edit_menu->insertItem(QPixmap(locate("data", "kvoctrain/edit-row.xpm")), i18n("&Edit Selected Area..."), ID_EDIT_ROW );
   edit_menu->insertItem(QPixmap(locate("data", "kvoctrain/delete-row.xpm")), i18n("&Remove Selected Area"), ID_REMOVE_ROW );
-  edit_menu->insertItem(KGlobal::iconLoader()->loadIcon("filesave", KIcon::Small), i18n("Sa&ve Selected Area.."), ID_SAVE_ROW );
+  edit_menu->insertItem(KGlobal::iconLoader()->loadIcon("filesave", KIcon::Small), i18n("Sa&ve Selected Area..."), ID_SAVE_ROW );
   connect( edit_menu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowEdit()));
   connect(QApplication::clipboard(),SIGNAL(dataChanged()), this,SLOT(clipboardChanged()));
   clipboardChanged();
@@ -300,19 +315,19 @@ void kvoctrainApp::initMenuBar()
   // menuBar entry voc_menu
   voc_menu = new QPopupMenu();
   voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/statist.xpm")), i18n("Show &Statistics"), ID_SHOW_STAT );
-  voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/rand-less.xpm")), i18n("Assign &Lessons"), ID_RAND_CREATE );
+  voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/rand-less.xpm")), i18n("Assign &Lessons..."), ID_RAND_CREATE );
   voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/cleanup.xpm")), i18n("&Clean Up"), ID_CLEANUP );
   voc_menu->insertSeparator();
   QPopupMenu *add_m = new QPopupMenu();
   voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/append-col.xpm")), i18n("&Append Language"), add_m, ID_APPEND_LANG );
   QPopupMenu *set_m = new QPopupMenu();
-  voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), ("Set &language"), set_m, ID_SET_LANG );
+  voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), set_m, ID_SET_LANG );
   QPopupMenu *remove_m = new QPopupMenu();
   voc_menu->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")), i18n("&Remove Language"), remove_m, ID_REMOVE_LANG);
 
   voc_menu->insertSeparator();
-  voc_menu->insertItem(i18n("Document &Properties"), ID_DOC_PROPS );
-  voc_menu->insertItem(i18n("Lan&guage Properties"), ID_DOC_PROPS_LANG );
+  voc_menu->insertItem(i18n("Document &Properties..."), ID_DOC_PROPS );
+  voc_menu->insertItem(i18n("Lan&guage Properties..."), ID_DOC_PROPS_LANG );
   connect( voc_menu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowVocabulary()));
 
   ///////////////////////////////////////////////////////////////////
@@ -326,8 +341,8 @@ void kvoctrainApp::initMenuBar()
   opts_menu->insertItem(i18n("St&atusbar"), ID_VIEW_STATUSBAR );
   opts_menu->insertItem(i18n("&Inline Editing"), ID_VIEW_INLINE );
   opts_menu->insertSeparator();
-  opts_menu->insertItem(QPixmap(locate("data", "kvoctrain/gen-conf.xpm")), i18n("General &Options"), ID_GENERAL_OPTIONS );
-  opts_menu->insertItem(QPixmap(locate("data", "kvoctrain/query-conf.xpm")), i18n("&Query Options"), ID_QUERY_OPTIONS );
+  opts_menu->insertItem(QPixmap(locate("data", "kvoctrain/gen-conf.xpm")), i18n("General &Options..."), ID_GENERAL_OPTIONS );
+  opts_menu->insertItem(QPixmap(locate("data", "kvoctrain/query-conf.xpm")), i18n("&Query Options..."), ID_QUERY_OPTIONS );
   opts_menu->insertItem(QPixmap(locate("data", "kvoctrain/conf-save.xpm")),i18n("&Save Options"), ID_SAVE_OPTIONS );
   connect( opts_menu, SIGNAL(aboutToShow()), this, SLOT(aboutToShowOptions()));
 
@@ -402,7 +417,7 @@ void kvoctrainApp::initToolBar()
   lessons->setFocusPolicy(QWidget::NoFocus);
 
   toolBar()->insertSeparator();
-  toolBar()->insertButton(KGlobal::iconLoader()->loadIcon("find", KIcon::Toolbar), ID_SEARCH_CLIP, true, i18n("Search from Clipboard"));
+  toolBar()->insertButton(KGlobal::iconLoader()->loadIcon("find", KIcon::Toolbar), ID_SEARCH_CLIP, true, i18n("Search From Clipboard"));
   toolBar()->insertLined ("", ID_TSEARCH, SIGNAL(textChanged(const QString&)), this, SLOT(slotResumeSearch(const QString&)), true, i18n("Smart Search"));
   searchLine = toolBar()->getLined (ID_TSEARCH);
   searchLine->setFocusPolicy(QWidget::ClickFocus);
