@@ -1,5 +1,5 @@
 /* -*- C++ -*-
-  $Id: XmlReader.h,v 1.1.4.1 2002/04/12 10:09:28 coolo Exp $
+  $Id: XmlReader.h,v 1.2 2002/04/12 10:09:56 coolo Exp $
 
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
@@ -9,7 +9,7 @@
   -----------------------------------------------------------------------
 
   $Log: XmlReader.h,v $
-  Revision 1.1.4.1  2002/04/12 10:09:28  coolo
+  Revision 1.2  2002/04/12 10:09:56  coolo
   replacing tons of these (for gcc 3):
   -      queryList.erase(&queryList[i], &queryList[i+1]);
   +      queryList.erase(queryList.begin() + i);
