@@ -1,6 +1,6 @@
 /***************************************************************************
 
-    $Id: rowtable.cpp,v 1.23 2002/03/13 09:25:42 staikos Exp $
+    $Id: rowtable.cpp,v 1.23.4.1 2003/08/03 11:06:10 domi Exp $
 
                  table view to kvoctrain document
 
@@ -14,6 +14,9 @@
     -----------------------------------------------------------------------
 
     $Log: rowtable.cpp,v $
+    Revision 1.23.4.1  2003/08/03 11:06:10  domi
+    backport: fix a crash on setting 'Inline Editing'
+
     Revision 1.23  2002/03/13 09:25:42  staikos
     Don't crash on exit
 
@@ -292,7 +295,9 @@ void RowTable::setInlineEnabled(bool state)
            || (type == QTableItem::OnTyping && !state)
           )) {
        endEdit(defaultItem->row(), defaultItem->col(), true, false);
-       takeItem(defaultItem);
+       // the qtableitem destructor does this too, and doing it twice
+       // seems to cause a crash..
+//       takeItem(defaultItem);
        delete defaultItem;
        defaultItem = 0;
        if (state) {
